/*
 * [WriteManifests.java]
 *
 * Summary: Prepare zip and file manifests.
 *
 * Copyright: (c) 2009-2017 Roedy Green, Canadian Mind Products, http://mindprod.com
 *
 * Licence: This software may be copied and used freely for any purpose but military.
 *          http://mindprod.com/contact/nonmil.html
 *
 * Requires: JDK 1.8+
 *
 * Created with: JetBrains IntelliJ IDEA IDE http://www.jetbrains.com/idea/
 *
 * Version History:
 *  1.0 2007-07-18 Created with IntelliJ IDEA.
 */
package com.mindprod.replicatorsender;

import com.mindprod.replicatorcommon.Config;
import com.mindprod.replicatorcommon.MiniFD;
import com.mindprod.replicatorcommon.MiniZD;
import com.mindprod.replicatorcommon.ReplicatorCommon;

import java.io.File;
import java.io.FileOutputStream;
import java.io.IOException;
import java.io.ObjectOutputStream;
import java.util.ArrayList;
import java.util.zip.GZIPOutputStream;

/**
 * Prepare zip and file manifests.
 *
 * @author Roedy Green, Canadian Mind Products
 * @version 1.0 2007-07-18 Created with IntelliJ IDEA.
 * @since 2009
 */
final class WriteManifests
    {
    /**
     * Save list of distributed files to zipdetailedmanifest.ser so client can verify. If change format, fix
     * ReplicatorValidate.
     */
    static void prepareFileManifestSer()
        {
        // should already be in order. Does no work if it is.
        ReplicatorSender.combinedFilesAndDeletions.sort( MaxiFD.BY_CLUMPING_AND_FILENAME );
        // save just file info for client.
        final String fileManifestFilename = ConfigForSender.SENDER_ZIP_STAGING_DIR
                                            + File.separatorChar
                                            + Config.ZIPDETAILEDMANIFEST_SER;
        try
            {
            final FileOutputStream fos =
                    new FileOutputStream( fileManifestFilename );
            final GZIPOutputStream gzos =
                    new GZIPOutputStream( fos, 4 * 1024 );
            final ObjectOutputStream oos = new ObjectOutputStream( gzos );
            /* client just wants MiniFDs */
            final MiniFD[] shortFilesAndDeletions =
                    new MiniFD[ ReplicatorSender.combinedFilesAndDeletions.size() ];
            // we don't need the attached MaxiZD objects
            int i = 0;
            for ( MaxiFD fileToDistribute : ReplicatorSender.combinedFilesAndDeletions )
                {
                shortFilesAndDeletions[ i++ ] = fileToDistribute.strip();
                }
            // version marker on head so can easily tell if have wrong version
            // or wrong file type.
            oos.writeObject( MiniFD.serialVersionUID );
            oos.writeObject( shortFilesAndDeletions );
            oos.close();
            }
        catch ( IOException e )
            {
            ReplicatorCommon.fatal( "Unable to save "
                                    + fileManifestFilename
                                    + " file."
                                    + "\n"
                                    + e.getMessage() );
            }
        }

    /**
     * Prepare a manifest of just the active zips for the client. If change format, fix ReplicatorValidate.
     */
    static void prepareZipManifestSer()
        {
        // save just zip info for client.
        final String zipManifestFilename = ConfigForSender.SENDER_ZIP_STAGING_DIR
                                           + File.separatorChar
                                           + Config.ZIPMANIFEST_SER;
        try
            {
            final FileOutputStream fos =
                    new FileOutputStream( zipManifestFilename );
            final GZIPOutputStream gzos =
                    new GZIPOutputStream( fos, 4 * 1024/* buffsize */ );
            final ObjectOutputStream oos = new ObjectOutputStream( gzos );
            final int size = ReplicatorSender.allZips.size();
            final ArrayList<MiniZD> allMiniZips = new ArrayList<>( size );
            // prune list down to bare minimum, only what client needs.
            for ( MaxiZD zd : ReplicatorSender.allZips )
                {
                if ( zd.status == ZDStatus.B_CREATED )
                    {
                    // demote back to a MiniZD
                    allMiniZips.add( zd.strip() );
                    }
                } // end for
            // prune back to a raw array for ultimate simplicity for the client.
            oos.writeObject( MiniZD.serialVersionUID );
            oos.writeObject( allMiniZips.toArray( new MiniZD[ allMiniZips
                    .size() ] ) );
            oos.close();
            }
        catch ( IOException e )
            {
            ReplicatorCommon.fatal( "Unable to save "
                                    + zipManifestFilename
                                    + " file."
                                    + "\n"
                                    + e.getMessage() );
            }
        }
    }
